==> keycloak-model-map-17.0.1-sources.jar: org/keycloak/models/map/user/MapUserEntityFieldDelegate.java <==
package org.keycloak.models.map.user;
public class MapUserEntityFieldDelegate extends org.keycloak.models.map.user.MapUserEntity.AbstractUserEntity implements org.keycloak.models.map.user.MapUserEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.user.MapUserEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserEntity> entityFieldDelegate;
    public MapUserEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getUsername() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.USERNAME);
    }
    @SuppressWarnings("unchecked") @Override public void setUsername(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.USERNAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getFirstName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.FIRST_NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setFirstName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.FIRST_NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getCreatedTimestamp() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.CREATED_TIMESTAMP);
    }
    @SuppressWarnings("unchecked") @Override public void setCreatedTimestamp(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.CREATED_TIMESTAMP, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getLastName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.LAST_NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setLastName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.LAST_NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getEmail() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.EMAIL);
    }
    @SuppressWarnings("unchecked") @Override public void setEmail(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.EMAIL, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isEnabled() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.ENABLED);
    }
    @SuppressWarnings("unchecked") @Override public void setEnabled(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.ENABLED, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isEmailVerified() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.EMAIL_VERIFIED);
    }
    @SuppressWarnings("unchecked") @Override public void setEmailVerified(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.EMAIL_VERIFIED, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getEmailConstraint() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.EMAIL_CONSTRAINT);
    }
    @SuppressWarnings("unchecked") @Override public void setEmailConstraint(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.EMAIL_CONSTRAINT, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,java.util.List<String>> getAttributes() {
        return (java.util.Map<String,java.util.List<String>>) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.ATTRIBUTES);
    }
    @SuppressWarnings("unchecked") @Override public java.util.List<String> getAttribute(String p0) {
        return (java.util.List<String>) entityFieldDelegate.mapGet(org.keycloak.models.map.user.MapUserEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setAttributes(java.util.Map<String,java.util.List<String>> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setAttribute(String p0, java.util.List<String> p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.user.MapUserEntityFields.ATTRIBUTES, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public void removeAttribute(String p0) {
        entityFieldDelegate.mapRemove(org.keycloak.models.map.user.MapUserEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getRequiredActions() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.REQUIRED_ACTIONS);
    }
    @SuppressWarnings("unchecked") @Override public void setRequiredActions(java.util.Set<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.REQUIRED_ACTIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addRequiredAction(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.user.MapUserEntityFields.REQUIRED_ACTIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeRequiredAction(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.user.MapUserEntityFields.REQUIRED_ACTIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.List<org.keycloak.models.map.user.MapUserCredentialEntity> getCredentials() {
        return (java.util.List<org.keycloak.models.map.user.MapUserCredentialEntity>) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.CREDENTIALS);
    }
    @SuppressWarnings("unchecked") @Override public void setCredentials(java.util.List<org.keycloak.models.map.user.MapUserCredentialEntity> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.CREDENTIALS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addCredential(org.keycloak.models.map.user.MapUserCredentialEntity p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.user.MapUserEntityFields.CREDENTIALS, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean removeCredential(org.keycloak.models.map.user.MapUserCredentialEntity p0) {
        return (Boolean) entityFieldDelegate.collectionRemove(org.keycloak.models.map.user.MapUserEntityFields.CREDENTIALS, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<org.keycloak.models.map.user.MapUserFederatedIdentityEntity> getFederatedIdentities() {
        return (java.util.Set<org.keycloak.models.map.user.MapUserFederatedIdentityEntity>) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.FEDERATED_IDENTITIES);
    }
    @SuppressWarnings("unchecked") @Override public void setFederatedIdentities(java.util.Set<org.keycloak.models.map.user.MapUserFederatedIdentityEntity> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.FEDERATED_IDENTITIES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addFederatedIdentity(org.keycloak.models.map.user.MapUserFederatedIdentityEntity p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.user.MapUserEntityFields.FEDERATED_IDENTITIES, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean removeFederatedIdentity(org.keycloak.models.map.user.MapUserFederatedIdentityEntity p0) {
        return (Boolean) entityFieldDelegate.collectionRemove(org.keycloak.models.map.user.MapUserEntityFields.FEDERATED_IDENTITIES, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<org.keycloak.models.map.user.MapUserConsentEntity> getUserConsents() {
        return (java.util.Set<org.keycloak.models.map.user.MapUserConsentEntity>) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.USER_CONSENTS);
    }
    @SuppressWarnings("unchecked") @Override public void setUserConsents(java.util.Set<org.keycloak.models.map.user.MapUserConsentEntity> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.USER_CONSENTS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addUserConsent(org.keycloak.models.map.user.MapUserConsentEntity p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.user.MapUserEntityFields.USER_CONSENTS, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean removeUserConsent(org.keycloak.models.map.user.MapUserConsentEntity p0) {
        return (Boolean) entityFieldDelegate.collectionRemove(org.keycloak.models.map.user.MapUserEntityFields.USER_CONSENTS, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getGroupsMembership() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.GROUPS_MEMBERSHIP);
    }
    @SuppressWarnings("unchecked") @Override public void setGroupsMembership(java.util.Set<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.GROUPS_MEMBERSHIP, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addGroupsMembership(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.user.MapUserEntityFields.GROUPS_MEMBERSHIP, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeGroupsMembership(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.user.MapUserEntityFields.GROUPS_MEMBERSHIP, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getRolesMembership() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.ROLES_MEMBERSHIP);
    }
    @SuppressWarnings("unchecked") @Override public void setRolesMembership(java.util.Set<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.ROLES_MEMBERSHIP, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addRolesMembership(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.user.MapUserEntityFields.ROLES_MEMBERSHIP, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeRolesMembership(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.user.MapUserEntityFields.ROLES_MEMBERSHIP, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getFederationLink() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.FEDERATION_LINK);
    }
    @SuppressWarnings("unchecked") @Override public void setFederationLink(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.FEDERATION_LINK, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getServiceAccountClientLink() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.SERVICE_ACCOUNT_CLIENT_LINK);
    }
    @SuppressWarnings("unchecked") @Override public void setServiceAccountClientLink(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.SERVICE_ACCOUNT_CLIENT_LINK, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getNotBefore() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.NOT_BEFORE);
    }
    @SuppressWarnings("unchecked") @Override public void setNotBefore(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.NOT_BEFORE, p0);
    }
}

==> keycloak-model-map-18.0.0-sources.jar: org/keycloak/models/map/user/MapUserEntityFieldDelegate.java <==
package org.keycloak.models.map.user;
public class MapUserEntityFieldDelegate extends org.keycloak.models.map.user.MapUserEntity.AbstractUserEntity implements org.keycloak.models.map.user.MapUserEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.user.MapUserEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserEntity> entityFieldDelegate;
    public MapUserEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.user.MapUserEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,java.util.List<String>> getAttributes() {
        return (java.util.Map<String,java.util.List<String>>) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.ATTRIBUTES);
    }
    @SuppressWarnings("unchecked") @Override public void setAttributes(java.util.Map<String,java.util.List<String>> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.List<String> getAttribute(String p0) {
        return (java.util.List<String>) entityFieldDelegate.mapGet(org.keycloak.models.map.user.MapUserEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setAttribute(String p0, java.util.List<String> p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.user.MapUserEntityFields.ATTRIBUTES, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public void removeAttribute(String p0) {
        entityFieldDelegate.mapRemove(org.keycloak.models.map.user.MapUserEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getUsername() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.USERNAME);
    }
    @SuppressWarnings("unchecked") @Override public void setUsername(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.USERNAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getFirstName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.FIRST_NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setFirstName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.FIRST_NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getCreatedTimestamp() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.CREATED_TIMESTAMP);
    }
    @SuppressWarnings("unchecked") @Override public void setCreatedTimestamp(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.CREATED_TIMESTAMP, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getLastName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.LAST_NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setLastName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.LAST_NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getEmail() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.EMAIL);
    }
    @SuppressWarnings("unchecked") @Override public void setEmail(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.EMAIL, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isEnabled() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.ENABLED);
    }
    @SuppressWarnings("unchecked") @Override public void setEnabled(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.ENABLED, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isEmailVerified() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.EMAIL_VERIFIED);
    }
    @SuppressWarnings("unchecked") @Override public void setEmailVerified(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.EMAIL_VERIFIED, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getEmailConstraint() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.EMAIL_CONSTRAINT);
    }
    @SuppressWarnings("unchecked") @Override public void setEmailConstraint(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.EMAIL_CONSTRAINT, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getRequiredActions() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.REQUIRED_ACTIONS);
    }
    @SuppressWarnings("unchecked") @Override public void setRequiredActions(java.util.Set<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.REQUIRED_ACTIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addRequiredAction(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.user.MapUserEntityFields.REQUIRED_ACTIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeRequiredAction(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.user.MapUserEntityFields.REQUIRED_ACTIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.List<org.keycloak.models.map.user.MapUserCredentialEntity> getCredentials() {
        return (java.util.List<org.keycloak.models.map.user.MapUserCredentialEntity>) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.CREDENTIALS);
    }
    @SuppressWarnings("unchecked") @Override public void setCredentials(java.util.List<org.keycloak.models.map.user.MapUserCredentialEntity> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.CREDENTIALS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addCredential(org.keycloak.models.map.user.MapUserCredentialEntity p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.user.MapUserEntityFields.CREDENTIALS, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean removeCredential(org.keycloak.models.map.user.MapUserCredentialEntity p0) {
        return (Boolean) entityFieldDelegate.collectionRemove(org.keycloak.models.map.user.MapUserEntityFields.CREDENTIALS, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<org.keycloak.models.map.user.MapUserFederatedIdentityEntity> getFederatedIdentities() {
        return (java.util.Set<org.keycloak.models.map.user.MapUserFederatedIdentityEntity>) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.FEDERATED_IDENTITIES);
    }
    @SuppressWarnings("unchecked") @Override public void setFederatedIdentities(java.util.Set<org.keycloak.models.map.user.MapUserFederatedIdentityEntity> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.FEDERATED_IDENTITIES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addFederatedIdentity(org.keycloak.models.map.user.MapUserFederatedIdentityEntity p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.user.MapUserEntityFields.FEDERATED_IDENTITIES, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean removeFederatedIdentity(org.keycloak.models.map.user.MapUserFederatedIdentityEntity p0) {
        return (Boolean) entityFieldDelegate.collectionRemove(org.keycloak.models.map.user.MapUserEntityFields.FEDERATED_IDENTITIES, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<org.keycloak.models.map.user.MapUserConsentEntity> getUserConsents() {
        return (java.util.Set<org.keycloak.models.map.user.MapUserConsentEntity>) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.USER_CONSENTS);
    }
    @SuppressWarnings("unchecked") @Override public void setUserConsents(java.util.Set<org.keycloak.models.map.user.MapUserConsentEntity> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.USER_CONSENTS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addUserConsent(org.keycloak.models.map.user.MapUserConsentEntity p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.user.MapUserEntityFields.USER_CONSENTS, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean removeUserConsent(org.keycloak.models.map.user.MapUserConsentEntity p0) {
        return (Boolean) entityFieldDelegate.collectionRemove(org.keycloak.models.map.user.MapUserEntityFields.USER_CONSENTS, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getGroupsMembership() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.GROUPS_MEMBERSHIP);
    }
    @SuppressWarnings("unchecked") @Override public void setGroupsMembership(java.util.Set<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.GROUPS_MEMBERSHIP, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addGroupsMembership(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.user.MapUserEntityFields.GROUPS_MEMBERSHIP, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeGroupsMembership(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.user.MapUserEntityFields.GROUPS_MEMBERSHIP, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getRolesMembership() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.ROLES_MEMBERSHIP);
    }
    @SuppressWarnings("unchecked") @Override public void setRolesMembership(java.util.Set<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.ROLES_MEMBERSHIP, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addRolesMembership(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.user.MapUserEntityFields.ROLES_MEMBERSHIP, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeRolesMembership(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.user.MapUserEntityFields.ROLES_MEMBERSHIP, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getFederationLink() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.FEDERATION_LINK);
    }
    @SuppressWarnings("unchecked") @Override public void setFederationLink(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.FEDERATION_LINK, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getServiceAccountClientLink() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.SERVICE_ACCOUNT_CLIENT_LINK);
    }
    @SuppressWarnings("unchecked") @Override public void setServiceAccountClientLink(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.SERVICE_ACCOUNT_CLIENT_LINK, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getNotBefore() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.user.MapUserEntityFields.NOT_BEFORE);
    }
    @SuppressWarnings("unchecked") @Override public void setNotBefore(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.user.MapUserEntityFields.NOT_BEFORE, p0);
    }
}
